@@ -24,13 +24,15 @@ from rich.style import Style
 
 from . import errors
 from ._cells import cell_len
+from ._context import visible_screen_stack
 from ._loop import loop_last
 from .geometry import NULL_OFFSET, Offset, Region, Size
-from .strip import Strip
+from .strip import Strip, StripRenderable
 
 if TYPE_CHECKING:
     from typing_extensions import TypeAlias
 
+    from .screen import Screen
     from .widget import Widget
 
 
@@ -370,7 +372,7 @@ class Compositor:
             return {}
         if self._full_map_invalidated:
             self._full_map_invalidated = False
-            map, widgets = self._arrange_root(self.root, self.size, visible_only=False)
+            map, _widgets = self._arrange_root(self.root, self.size, visible_only=False)
             self._full_map = map
             self._visible_widgets = None
             self._visible_map = None
@@ -446,7 +448,7 @@ class Compositor:
                 layer_order: The order of the widget in its layer.
                 clip: The clipping region (i.e. the viewport which contains it).
                 visible: Whether the widget should be visible by default.
-                    This may be overriden by the CSS rule `visibility`.
+                    This may be overridden by the CSS rule `visibility`.
             """
             visibility = widget.styles.get_rule("visibility")
             if visibility is not None:
@@ -482,7 +484,6 @@ class Compositor:
                     # Arrange the layout
                     arrange_result = widget._arrange(child_region.size)
                     arranged_widgets = arrange_result.widgets
-                    spacing = arrange_result.spacing
                     widgets.update(arranged_widgets)
 
                     if visible_only:
@@ -511,9 +512,7 @@ class Compositor:
                         if fixed:
                             widget_region = sub_region + placement_offset
                         else:
-                            total_region = total_region.union(
-                                sub_region.grow(spacing + margin)
-                            )
+                            total_region = total_region.union(sub_region.grow(margin))
                             widget_region = sub_region + placement_scroll_offset
 
                         widget_order = order + (
@@ -543,7 +542,7 @@ class Compositor:
                             container_region
                         ):
                             map[chrome_widget] = _MapGeometry(
-                                chrome_region + layout_offset,
+                                chrome_region,
                                 order,
                                 clip,
                                 container_size,
@@ -681,6 +680,7 @@ class Compositor:
         x -= region.x
         y -= region.y
 
+        visible_screen_stack.set(widget.app._background_screens)
         lines = widget.render_lines(Region(0, y, region.width, 1))
 
         if not lines:
@@ -708,6 +708,11 @@ class Compositor:
         if self.root is None:
             raise errors.NoWidget("Widget is not in layout")
         try:
+            if self._full_map is not None:
+                try:
+                    return self._full_map[widget]
+                except KeyError:
+                    pass
             if self._visible_map is not None:
                 try:
                     return self._visible_map[widget]
@@ -756,6 +761,9 @@ class Compositor:
     ) -> Iterable[tuple[Region, Region, list[Strip]]]:
         """Get rendered widgets (lists of segments) in the composition.
 
+        Args:
+            crop: Region to crop to, or `None` for entire screen.
+
         Returns:
             An iterable of <region>, <clip region>, and <strips>
         """
@@ -800,41 +808,84 @@ class Compositor:
                     _Region(delta_x, delta_y, new_width, new_height)
                 )
 
-    def render(self, full: bool = False) -> RenderableType | None:
-        """Render a layout.
+    def render_update(
+        self, full: bool = False, screen_stack: list[Screen] | None = None
+    ) -> RenderableType | None:
+        """Render an update renderable.
+
+        Args:
+            full: Enable full update, or `False` for a partial update.
 
         Returns:
-            A renderable
+            A renderable for the update, or `None` if no update was required.
         """
 
-        width, height = self.size
-        screen_region = Region(0, 0, width, height)
-
-        if full:
-            update_regions: set[Region] = set()
+        visible_screen_stack.set([] if screen_stack is None else screen_stack)
+        screen_region = self.size.region
+        if full or screen_region in self._dirty_regions:
+            return self.render_full_update()
         else:
-            update_regions = self._dirty_regions.copy()
-            if screen_region in update_regions:
-                # If one of the updates is the entire screen, then we only need one update
-                full = True
-        self._dirty_regions.clear()
+            return self.render_partial_update()
 
-        if full:
-            crop = screen_region
-            spans = []
-            is_rendered_line = lambda y: True
-        elif update_regions:
-            # Create a crop regions that surrounds all updates
+    def render_full_update(self) -> LayoutUpdate:
+        """Render a full update.
+
+        Returns:
+            A LayoutUpdate renderable.
+        """
+        screen_region = self.size.region
+        self._dirty_regions.clear()
+        crop = screen_region
+        chops = self._render_chops(crop, lambda y: True)
+        render_strips = [Strip.join(chop.values()) for chop in chops]
+        return LayoutUpdate(render_strips, screen_region)
+
+    def render_partial_update(self) -> ChopsUpdate | None:
+        """Render a partial update.
+
+        Returns:
+            A ChopsUpdate if there is anything to update, otherwise `None`.
+
+        """
+        screen_region = self.size.region
+        update_regions = self._dirty_regions.copy()
+        self._dirty_regions.clear()
+        if update_regions:
+            # Create a crop region that surrounds all updates.
             crop = Region.from_union(update_regions).intersection(screen_region)
             spans = list(self._regions_to_spans(update_regions))
             is_rendered_line = {y for y, _, _ in spans}.__contains__
         else:
             return None
+        chops = self._render_chops(crop, is_rendered_line)
+        chop_ends = [cut_set[1:] for cut_set in self.cuts]
+        return ChopsUpdate(chops, spans, chop_ends)
 
-        # Maps each cut on to a list of segments
+    def render_strips(self) -> list[Strip]:
+        """Render to a list of strips.
+
+        Returns:
+            A list of strips with the screen content.
+        """
+        chops = self._render_chops(self.size.region, lambda y: True)
+        render_strips = [Strip.join(chop.values()) for chop in chops]
+        return render_strips
+
+    def _render_chops(
+        self,
+        crop: Region,
+        is_rendered_line: Callable[[int], bool],
+    ) -> list[dict[int, Strip | None]]:
+        """Render update 'chops'.
+
+        Args:
+            crop: Region to crop to.
+            is_rendered_line: Callable to check if line should be rendered.
+
+        Returns:
+            Chops structure.
+        """
         cuts = self.cuts
-
-        # dict.fromkeys is a callable which takes a list of ints returns a dict which maps ints onto a Segment or None.
         fromkeys = cast("Callable[[list[int]], dict[int, Strip | None]]", dict.fromkeys)
         chops: list[dict[int, Strip | None]]
         chops = [fromkeys(cut_set[:-1]) for cut_set in cuts]
@@ -872,28 +923,24 @@ class Compositor:
                     if chops_line[cut] is None:
                         chops_line[cut] = strip
 
-        if full:
-            render_strips = [Strip.join(chop.values()) for chop in chops]
-            return LayoutUpdate(render_strips, screen_region)
-        else:
-            chop_ends = [cut_set[1:] for cut_set in cuts]
-            return ChopsUpdate(chops, spans, chop_ends)
+        return chops
 
-    def __rich_console__(
-        self, console: Console, options: ConsoleOptions
-    ) -> RenderResult:
-        if self._dirty_regions:
-            yield self.render() or ""
+    def __rich__(self) -> StripRenderable:
+        return StripRenderable(self.render_strips())
 
     def update_widgets(self, widgets: set[Widget]) -> None:
         """Update a given widget in the composition.
 
         Args:
-            console: Console instance.
-            widget: Widget to update.
+            widgets: Set of Widgets to update.
 
         """
-        self._full_map_invalidated = True
+        # If there are any *new* widgets we need to invalidate the full map
+        if not self._full_map_invalidated and not widgets.issubset(
+            self.visible_widgets.keys()
+        ):
+            self._full_map_invalidated = True
+
         regions: list[Region] = []
         add_region = regions.append
         get_widget = self.visible_widgets.__getitem__
