@@ -18,13 +18,13 @@ class DurationParseError(DurationError):
 def _duration_as_seconds(duration: str) -> float:
     """
     Args:
-        duration (str): A string of the form ``"2s"`` or ``"300ms"``, representing 2 seconds and
+        duration: A string of the form ``"2s"`` or ``"300ms"``, representing 2 seconds and
             300 milliseconds respectively. If no unit is supplied, e.g. ``"2"``, then the duration is
             assumed to be in seconds.
     Raises:
         DurationParseError: If the argument ``duration`` is not a valid duration string.
     Returns:
-        float: The duration in seconds.
+        The duration in seconds.
 
     """
     match = _match_duration(duration)
