@@ -295,11 +295,6 @@ class App(Generic[ReturnType], DOMNode):
         css_path: CSSPathType | None = None,
         watch_css: bool = False,
     ):
-        # N.B. This must be done *before* we call the parent constructor, because MessagePump's
-        # constructor instantiates a `asyncio.PriorityQueue` and in Python versions older than 3.10
-        # this will create some first references to an asyncio loop.
-        _init_uvloop()
-
         super().__init__()
         self.features: frozenset[FeatureFlag] = parse_features(os.getenv("TEXTUAL", ""))
 
@@ -319,7 +314,7 @@ class App(Generic[ReturnType], DOMNode):
 
         self.console = Console(
             file=file,
-            markup=False,
+            markup=True,
             highlight=False,
             emoji=False,
             legacy_windows=False,
@@ -650,6 +645,17 @@ class App(Generic[ReturnType], DOMNode):
         except IndexError:
             raise ScreenStackError("No screens on stack") from None
 
+    @property
+    def _background_screens(self) -> list[Screen]:
+        """A list of screens that may be visible due to background opacity (top-most first, not including current screen)."""
+        screens: list[Screen] = []
+        for screen in reversed(self._screen_stack[:-1]):
+            screens.append(screen)
+            if screen.styles.background.a == 1:
+                break
+        background_screens = screens[::-1]
+        return background_screens
+
     @property
     def size(self) -> Size:
         """Size: The size of the terminal."""
@@ -796,7 +802,9 @@ class App(Generic[ReturnType], DOMNode):
             record=True,
             legacy_windows=False,
         )
-        screen_render = self.screen._compositor.render(full=True)
+        screen_render = self.screen._compositor.render_update(
+            full=True, screen_stack=self.app._background_screens
+        )
         console.print(screen_render)
         return console.export_svg(title=title or self.title)
 
@@ -1073,7 +1081,6 @@ class App(Generic[ReturnType], DOMNode):
                 self.bell()
             else:
                 self.stylesheet = stylesheet
-                self.reset_styles()
                 self.stylesheet.update(self)
                 self.screen.refresh(layout=True)
 
@@ -1307,6 +1314,8 @@ class App(Generic[ReturnType], DOMNode):
             The screen that was replaced.
 
         """
+        if self._screen_stack:
+            self.screen.refresh()
         screen.post_message(events.ScreenSuspend())
         self.log.system(f"{screen} SUSPENDED")
         if not self.is_screen_installed(screen) and screen not in self._screen_stack:
@@ -1321,9 +1330,17 @@ class App(Generic[ReturnType], DOMNode):
             screen: A Screen instance or the name of an installed screen.
 
         """
+        if not isinstance(screen, (Screen, str)):
+            raise TypeError(
+                f"push_screen requires a Screen instance or str; not {screen!r}"
+            )
+
+        if self._screen_stack:
+            self.screen.post_message(events.ScreenSuspend())
+            self.screen.refresh()
         next_screen, await_mount = self._get_screen(screen)
         self._screen_stack.append(next_screen)
-        self.screen.post_message(events.ScreenResume())
+        next_screen.post_message(events.ScreenResume())
         self.log.system(f"{self.screen} is current (PUSHED)")
         return await_mount
 
@@ -1334,6 +1351,10 @@ class App(Generic[ReturnType], DOMNode):
             screen: Either a Screen object or screen name (the `name` argument when installed).
 
         """
+        if not isinstance(screen, (Screen, str)):
+            raise TypeError(
+                f"switch_screen requires a Screen instance or str; not {screen!r}"
+            )
         if self.screen is not screen:
             self._replace_screen(self._screen_stack.pop())
             next_screen, await_mount = self._get_screen(screen)
@@ -1446,9 +1467,9 @@ class App(Generic[ReturnType], DOMNode):
             if self.mouse_over is not widget:
                 try:
                     if self.mouse_over is not None:
-                        self.mouse_over._forward_event(events.Leave())
+                        self.mouse_over.post_message(events.Leave())
                     if widget is not None:
-                        widget._forward_event(events.Enter())
+                        widget.post_message(events.Enter())
                 finally:
                     self.mouse_over = widget
 
@@ -1578,6 +1599,7 @@ class App(Generic[ReturnType], DOMNode):
                     try:
                         await self._dispatch_message(events.Compose())
                         await self._dispatch_message(events.Mount())
+                        self.check_idle()
                     finally:
                         self._mounted_event.set()
 
@@ -1680,7 +1702,7 @@ class App(Generic[ReturnType], DOMNode):
             widgets = compose(self)
         except TypeError as error:
             raise TypeError(
-                f"{self!r} compose() returned an invalid response; {error}"
+                f"{self!r} compose() method returned an invalid result; {error}"
             ) from error
 
         await self.mount_all(widgets)
@@ -1938,22 +1960,37 @@ class App(Generic[ReturnType], DOMNode):
 
     @property
     def _binding_chain(self) -> list[tuple[DOMNode, Bindings]]:
-        """Get a chain of nodes and bindings to consider. If no widget is focused, returns the bindings from both the screen and the app level bindings. Otherwise, combines all the bindings from the currently focused node up the DOM to the root App.
+        """Get a chain of nodes and bindings to consider.
+        If no widget is focused, returns the bindings from both the screen and the app level bindings.
+        Otherwise, combines all the bindings from the currently focused node up the DOM to the root App.
 
         Returns:
             List of DOM nodes and their bindings.
         """
         focused = self.focused
         namespace_bindings: list[tuple[DOMNode, Bindings]]
+        screen = self.screen
+
         if focused is None:
-            namespace_bindings = [
-                (self.screen, self.screen._bindings),
-                (self, self._bindings),
-            ]
+            if screen.is_modal:
+                namespace_bindings = [
+                    (self.screen, self.screen._bindings),
+                ]
+            else:
+                namespace_bindings = [
+                    (self.screen, self.screen._bindings),
+                    (self, self._bindings),
+                ]
         else:
-            namespace_bindings = [
-                (node, node._bindings) for node in focused.ancestors_with_self
-            ]
+            if screen.is_modal:
+                namespace_bindings = [
+                    (node, node._bindings) for node in focused.ancestors
+                ]
+            else:
+                namespace_bindings = [
+                    (node, node._bindings) for node in focused.ancestors_with_self
+                ]
+
         return namespace_bindings
 
     async def check_bindings(self, key: str, priority: bool = False) -> bool:
@@ -2127,6 +2164,8 @@ class App(Generic[ReturnType], DOMNode):
     async def _on_resize(self, event: events.Resize) -> None:
         event.stop()
         self.screen.post_message(event)
+        for screen in self._background_screens:
+            screen.post_message(event)
 
     def _detach_from_dom(self, widgets: list[Widget]) -> list[Widget]:
         """Detach a list of widgets from the DOM.
@@ -2371,29 +2410,3 @@ class App(Generic[ReturnType], DOMNode):
     def _end_update(self) -> None:
         if self._sync_available:
             self.console.file.write(SYNC_END)
-
-
-_uvloop_init_done: bool = False
-
-
-def _init_uvloop() -> None:
-    """Import and install the `uvloop` asyncio policy, if available.
-
-    This is done only once, even if the function is called multiple times.
-
-    This is provided as a nicety for users that have `uvloop` installed independently
-    of Textual, as `uvloop` is not listed as a Textual dependency.
-    """
-    global _uvloop_init_done
-
-    if _uvloop_init_done:
-        return
-
-    try:
-        import uvloop  # type: ignore[reportMissingImports]
-    except ImportError:
-        pass
-    else:
-        uvloop.install()  # type: ignore[reportUnknownMemberType]
-
-    _uvloop_init_done = True
