@@ -9,10 +9,7 @@ import termios
 import tty
 from codecs import getincrementaldecoder
 from threading import Event, Thread
-from typing import TYPE_CHECKING, Any
-
-if TYPE_CHECKING:
-    from rich.console import Console
+from typing import IO, Any
 
 import rich.repr
 
@@ -29,13 +26,22 @@ class LinuxDriver(Driver):
 
     def __init__(
         self,
-        console: "Console",
+        file: IO[str],
         target: "MessageTarget",
         *,
         debug: bool = False,
         size: tuple[int, int] | None = None,
     ) -> None:
-        super().__init__(console, target, debug=debug, size=size)
+        """Initialize a driver.
+
+        Args:
+            file: A file-like object open for writing unicode.
+            target: The message target (expected to be the app).
+            debug: Enabled debug mode.
+            size: Initial size of the terminal or `None` to detect.
+        """
+        super().__init__(file, target, debug=debug, size=size)
+        self._file = file
         self.fileno = sys.stdin.fileno()
         self.attrs_before: list[Any] | None = None
         self.exit_event = Event()
@@ -45,6 +51,11 @@ class LinuxDriver(Driver):
         yield "debug", self._debug
 
     def _get_terminal_size(self) -> tuple[int, int]:
+        """Detect the terminal size.
+
+        Returns:
+            The size of the terminal as a tuple of (WIDTH, HEIGHT).
+        """
         width: int | None = 80
         height: int | None = 25
         import shutil
@@ -61,35 +72,46 @@ class LinuxDriver(Driver):
         return width, height
 
     def _enable_mouse_support(self) -> None:
-        write = self.console.file.write
+        """Enable reporting of mouse events."""
+        write = self.write
         write("\x1b[?1000h")  # SET_VT200_MOUSE
         write("\x1b[?1003h")  # SET_ANY_EVENT_MOUSE
         write("\x1b[?1015h")  # SET_VT200_HIGHLIGHT_MOUSE
         write("\x1b[?1006h")  # SET_SGR_EXT_MODE_MOUSE
 
         # write("\x1b[?1007h")
-        self.console.file.flush()
+        self.flush()
 
         # Note: E.g. lxterminal understands 1000h, but not the urxvt or sgr
         #       extensions.
 
     def _enable_bracketed_paste(self) -> None:
         """Enable bracketed paste mode."""
-        self.console.file.write("\x1b[?2004h")
+        self.write("\x1b[?2004h")
 
     def _disable_bracketed_paste(self) -> None:
         """Disable bracketed paste mode."""
-        self.console.file.write("\x1b[?2004l")
+        self.write("\x1b[?2004l")
 
     def _disable_mouse_support(self) -> None:
-        write = self.console.file.write
+        """Disable reporting of mouse events."""
+        write = self.write
         write("\x1b[?1000l")  #
         write("\x1b[?1003l")  #
         write("\x1b[?1015l")
         write("\x1b[?1006l")
-        self.console.file.flush()
+        self.flush()
+
+    def write(self, data: str) -> None:
+        """Write data to the output device.
+
+        Args:
+            data: Raw data.
+        """
+        self._file.write(data)
 
     def start_application_mode(self):
+        """Start application mode."""
         loop = asyncio.get_running_loop()
 
         def send_size_event():
@@ -107,7 +129,8 @@ class LinuxDriver(Driver):
 
         signal.signal(signal.SIGWINCH, on_terminal_resize)
 
-        self.console.set_alt_screen(True)
+        self.write("\x1b[?1049h")  # Alt screen
+
         self._enable_mouse_support()
         try:
             self.attrs_before = termios.tcgetattr(self.fileno)
@@ -132,10 +155,10 @@ class LinuxDriver(Driver):
 
             termios.tcsetattr(self.fileno, termios.TCSANOW, newattr)
 
-        self.console.show_cursor(False)
-        self.console.file.write("\033[?1003h\n")
-        self.console.file.flush()
-        self._key_thread = Thread(target=self.run_input_thread, args=(loop,))
+        self.write("\x1b[?25l")  # Hide cursor
+        self.write("\033[?1003h\n")
+        self.flush()
+        self._key_thread = Thread(target=self.run_input_thread)
         send_size_event()
         self._key_thread.start()
         self._request_terminal_sync_mode_support()
@@ -146,9 +169,9 @@ class LinuxDriver(Driver):
         # Terminals should ignore this sequence if not supported.
         # Apple terminal doesn't, and writes a single 'p' in to the terminal,
         # so we will make a special case for Apple terminal (which doesn't support sync anyway).
-        if self.console._environ.get("TERM_PROGRAM", "") != "Apple_Terminal":
-            self.console.file.write("\033[?2026$p")
-            self.console.file.flush()
+        if os.environ.get("TERM_PROGRAM", "") != "Apple_Terminal":
+            self.write("\033[?2026$p")
+            self.flush()
 
     @classmethod
     def _patch_lflag(cls, attrs: int) -> int:
@@ -170,6 +193,7 @@ class LinuxDriver(Driver):
         )
 
     def disable_input(self) -> None:
+        """Disable further input."""
         try:
             if not self.exit_event.is_set():
                 signal.signal(signal.SIGWINCH, signal.SIG_DFL)
@@ -184,6 +208,7 @@ class LinuxDriver(Driver):
             pass
 
     def stop_application_mode(self) -> None:
+        """Stop application mode, restore state."""
         self._disable_bracketed_paste()
         self.disable_input()
 
@@ -193,17 +218,12 @@ class LinuxDriver(Driver):
             except termios.error:
                 pass
 
-        with self.console:
-            self.console.set_alt_screen(False)
-            self.console.show_cursor(True)
+            # Alt screen false, show cursor
+            self.write("\x1b[?1049l" + "\x1b[?25h")
+            self.flush()
 
-    def run_input_thread(self, loop) -> None:
-        try:
-            self._run_input_thread(loop)
-        except Exception:
-            pass  # TODO: log
-
-    def _run_input_thread(self, loop) -> None:
+    def run_input_thread(self) -> None:
+        """Wait for input and dispatch events."""
         selector = selectors.DefaultSelector()
         selector.register(self.fileno, selectors.EVENT_READ)
 
