@@ -179,6 +179,15 @@ class MountError(WidgetError):
     """Error raised when there was a problem with the mount request."""
 
 
+class PseudoClasses(NamedTuple):
+    """Used for render/render_line based widgets that use caching. This structure can be used as a
+    cache-key."""
+
+    enabled: bool
+    focus: bool
+    hover: bool
+
+
 @rich.repr.auto
 class Widget(DOMNode):
     """
@@ -291,14 +300,20 @@ class Widget(DOMNode):
         if self in children:
             raise WidgetError("A widget can't be its own parent")
 
+        for child in children:
+            if not isinstance(child, Widget):
+                raise TypeError(
+                    f"Widget positional arguments must be Widget subclasses; not {child!r}"
+                )
+
         self._add_children(*children)
         self.disabled = disabled
 
     virtual_size = Reactive(Size(0, 0), layout=True)
     auto_width = Reactive(True)
     auto_height = Reactive(True)
-    has_focus = Reactive(False)
-    mouse_over = Reactive(False)
+    has_focus = Reactive(False, repaint=False)
+    mouse_over = Reactive(False, repaint=False)
     scroll_x = Reactive(0.0, repaint=False, layout=False)
     scroll_y = Reactive(0.0, repaint=False, layout=False)
     scroll_target_x = Reactive(0.0, repaint=False)
@@ -376,7 +391,7 @@ class Widget(DOMNode):
         return self.styles.offset.resolve(self.size, self.app.size)
 
     @offset.setter
-    def offset(self, offset: Offset) -> None:
+    def offset(self, offset: tuple[int, int]) -> None:
         self.styles.offset = ScalarOffset.from_offset(offset)
 
     def __enter__(self) -> Self:
@@ -2272,7 +2287,6 @@ class Widget(DOMNode):
             Tuples of scrollbar Widget and region.
 
         """
-
         show_vertical_scrollbar, show_horizontal_scrollbar = self.scrollbars_enabled
 
         scrollbar_size_horizontal = self.scrollbar_size_horizontal
@@ -2352,6 +2366,27 @@ class Widget(DOMNode):
                         break
                     node = node._parent
 
+    def get_pseudo_class_state(self) -> PseudoClasses:
+        """Get an object describing whether each pseudo class is present on this object or not.
+
+        Returns:
+            A PseudoClasses object describing the pseudo classes that are present.
+        """
+        node: MessagePump | None = self
+        disabled = False
+        while isinstance(node, Widget):
+            if node.disabled:
+                disabled = True
+                break
+            node = node._parent
+
+        pseudo_classes = PseudoClasses(
+            enabled=not disabled,
+            hover=self.mouse_over,
+            focus=self.has_focus,
+        )
+        return pseudo_classes
+
     def post_render(self, renderable: RenderableType) -> ConsoleRenderable:
         """Applies style attributes to the default renderable.
 
@@ -2560,7 +2595,7 @@ class Widget(DOMNode):
         *regions: Region,
         repaint: bool = True,
         layout: bool = False,
-    ) -> None:
+    ) -> Self:
         """Initiate a refresh of the widget.
 
         This method sets an internal flag to perform a refresh, which will be done on the
@@ -2576,8 +2611,11 @@ class Widget(DOMNode):
 
         Args:
             *regions: Additional screen regions to mark as dirty.
-            repaint: Repaint the widget (will call render() again). Defaults to True.
-            layout: Also layout widgets in the view. Defaults to False.
+            repaint: Repaint the widget (will call render() again).
+            layout: Also layout widgets in the view.
+
+        Returns:
+            The `Widget` instance.
         """
         if layout and not self._layout_required:
             self._layout_required = True
@@ -2595,6 +2633,7 @@ class Widget(DOMNode):
             self._repaint_required = True
 
         self.check_idle()
+        return self
 
     def remove(self) -> AwaitRemove:
         """Remove the Widget from the DOM (effectively deleting it).
@@ -2660,6 +2699,7 @@ class Widget(DOMNode):
         self._check_refresh()
 
     def _check_refresh(self) -> None:
+        """Check if a refresh was requested."""
         if self._parent is not None and not self._closing:
             try:
                 screen = self.screen
@@ -2676,12 +2716,14 @@ class Widget(DOMNode):
                     self._layout_required = False
                     screen.post_message(messages.Layout())
 
-    def focus(self, scroll_visible: bool = True) -> None:
+    def focus(self, scroll_visible: bool = True) -> Self:
         """Give focus to this widget.
 
         Args:
-            scroll_visible: Scroll parent to make this widget
-                visible. Defaults to True.
+            scroll_visible: Scroll parent to make this widget visible.
+
+        Returns:
+            The `Widget` instance.
         """
 
         def set_focus(widget: Widget):
@@ -2692,13 +2734,19 @@ class Widget(DOMNode):
                 pass
 
         self.app.call_later(set_focus, self)
+        return self
 
-    def reset_focus(self) -> None:
-        """Reset the focus (move it to the next available widget)."""
+    def reset_focus(self) -> Self:
+        """Reset the focus (move it to the next available widget).
+
+        Returns:
+            The `Widget` instance.
+        """
         try:
             self.screen._reset_focus(self)
         except NoScreen:
             pass
+        return self
 
     def capture_mouse(self, capture: bool = True) -> None:
         """Capture (or release) the mouse.
@@ -2766,7 +2814,7 @@ class Widget(DOMNode):
             widgets = compose(self)
         except TypeError as error:
             raise TypeError(
-                f"{self!r} compose() returned an invalid response; {error}"
+                f"{self!r} compose() method returned an invalid result; {error}"
             ) from error
         except Exception:
             self.app.panic(Traceback())
